"""VSA operation sets."""

from vsax.ops.binary import BinaryOperations
from vsax.ops.fhrr import FHRROperations
from vsax.ops.map import MAPOperations

__all__ = [
    "FHRROperations",
    "MAPOperations",
    "BinaryOperations",
]
